Learn R Programming

RcmdrPlugin.DCCV (version 0.2-0)

RcmdrPlugin.DCCV-package: R Commander Plug-in for Parametric Analysis of Dichotomous Choice Contingent Valuation Data

Description

This package adds menu items to the R Commander for parametric analysis of dichotomous choice contingent valuation (DCCV) data. CV is a question-based survey method to elicit individuals' preferences for goods and services. This package depends on functions regarding parametric DCCV analysis in the package DCchoice. See Carson and Hanemann (2005) <doi:10.1016/S1574-0099(05)02017-6> for DCCV.

Arguments

Acknowledgments

This work was supported by JSPS KAKENHI Grant Number JP20K06251.

Author

Hideo Aizaki

Details

This package is an R Commander plug-in package for parametric analysis of dichotomous choice contingent valuation (DCCV) data. It depends on DCchoice (Nakatani et al. 2020) and Rcmdr (Fox 2005, 2017; Fox and Bouchet-Valat 2020). Refer to DCchoice, Aizaki et al. (2014, 2022), and ‘Non-Market Valuation with R’ <https://nmvr.skr.jp/> for a brief introduction to DCCV in R. A manual for this package is available at <https://sites.google.com/view/r4sp/rcmdrplugin>

After successfully installing and loading RcmdrPlugin.DCCV, the R Commander window will appear, and then you will find ‘DCCV’ added to the top-level menus in the R Commander window.

Selecting ‘DCCV’ displays some menu items. When selecting a menu item, the corresponding dialog box opens. The following dialog boxes are provided by RcmdrPlugin.DCCV:

  • The dialog box for ‘Collect responses...’ displays three types of dialog boxes to collect user's responses to DCCV questions.

  • The dialog box for ‘Fit Model...’ implements a parametric analysis of DCCV data using sbchoice (single-bounded DCCV), oohbchoice (one-and-one-half-bounded DCCV), or dbchoice (double-bounded DCCV) in DCchoice.

  • The dialog box for ‘Calculate confidence intervals for WTP...’ calculates confidence intervals for willigness to pay (WTP) from the fitted model using krCI or bootCI in DCchoice.

  • The dialog box for ‘Draw survival function...’ draws a survival function of the fitted model using plot.sbchoice or plot.dbchoice in DCchoice.

References

Aizaki H, Nakatani T, Sato K, Fogarty J (2022) R Package DCchoice for Dichotomous Choice Contingent Valuation: A Contribution to Open Scientific Software and its Impact. Japanese Journal of Statistics and Data Science, 5: 871--884. DOI: 10.1007/s42081-022-00171-1.

Aizaki H, Nakatani T, Sato K (2014) Stated Preference Methods Using R. Chapman and Hall/CRC. DOI: 10.1201/b17292.

Carson RT, Hanemann WM (2005) Contingent valuation. In KG Maler, JR Vincent (eds), Handbook of Environmental Economics, Volume 2, Chapter 17, pp. 821--936. Elsevier. DOI: 10.1016/S1574-0099(05)02017-6.

Fox J (2005) The R Commander: A Basic Statistics Graphical User Interface to R. Journal of Statistical Software, 14(9): 1--42. DOI: 10.18637/jss.v014.i09.

Fox J (2017) Using the R Commander: A Point-and-Click Interface for R. Chapman and Hall/CRC. DOI: 10.1201/9781315380537.

Fox J, Bouchet-Valat M (2020) Rcmdr: R Commander. R package version 2.7-1. https://cran.r-project.org/package=Rcmdr.

Nakatani T, Aizaki H, Sato K (2020) DCchoice: Analyzing Dichotomous Choice Contingent Valuation Data. R package 0.0.17. https://cran.r-project.org/package=DCchoice.

Examples

Run this code
if (interactive()) {
  library(RcmdrPlugin.DCCV)
}

Run the code above in your browser using DataLab